@@ -35,7 +35,10 @@ sub run {
             rename $orig_file, $tar or errorf("Renaming $orig_file -> $tar failed: $!\n");
         }
 
-        my $config = CPAN::Uploader->read_config_file();
+        my $pause_config = ($opts->{pause_config})          ? $opts->{pause_config} 
+            : ($project->config->{release}->{pause_config}) ? $project->config->{release}->{pause_config}
+            :                                                 undef;
+        my $config = CPAN::Uploader->read_config_file($pause_config);
         my $uploader = CPAN::Uploader->new(+{
             tar => $tar,
             %$config
